#
# Conditional build:
%bcond_without	tests		# do not perform "make test"
#
%define		pdir	Readonly
%define		pnam	XS
Summary:	Readonly::XS - Companion module for Readonly.pm, to speed up read-only scalar variables
Name:		perl-Readonly-XS
Version:	1.05
Release:	16
# same as perl
License:	GPL v1+ or Artistic
Group:		Development/Languages/Perl
Source0:	http://www.cpan.org/modules/by-module/Readonly/%{pdir}-%{pnam}-%{version}.tar.gz
# Source0-md5:	df71f29abfcbd14c963f912d6d6ded6b
URL:		http://search.cpan.org/dist/Readonly-XS/
BuildRequires:	perl-devel >= 1:5.8.0
BuildRequires:	rpm-perlprov >= 4.1-13
%if %{with tests}
BuildRequires:	perl-Readonly >= 1.02
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
The Readonly module (q.v.) is an effective way to create
non-modifiable variables. However, it's relatively slow.

The reason it's slow is that is implements the read-only-ness of
variables via tied objects. This mechanism is inherently slow. Perl
simply has to do a lot of work under the hood to make tied variables
work.

This module corrects the speed problem, at least with respect to
scalar variables. When Readonly::XS is installed, Readonly uses it to
access the internals of scalar variables. Instead of creating a scalar
variable object and tying it, Readonly simply flips the SvREADONLY bit
in the scalar's FLAGS structure.

Readonly arrays and hashes are not sped up by this, since the
SvREADONLY flag only works for scalars. Arrays and hashes always use
the tie interface.

Why implement this as a separate module? Because not everyone can use
XS. Not everyone has a C compiler. Also, installations with a
statically-linked perl may not want to recompile their perl binary
just for this module. Rather than render Readonly.pm useless for these
people, the XS portion was put into a separate module.

%prep
%setup -q -n %{pdir}-%{pnam}-%{version}

%build
%{__perl} Makefile.PL \
	INSTALLDIRS=vendor
%{__make} \
	CC="%{__cc}" \
	OPTIMIZE="%{rpmcflags}"

%{?with_tests:%{__make} test}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} pure_install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc Changes README
%dir %{perl_vendorarch}/Readonly/
%{perl_vendorarch}/Readonly/*.pm
%dir %{perl_vendorarch}/auto/Readonly
%dir %{perl_vendorarch}/auto/Readonly/XS
%attr(755,root,root) %{perl_vendorarch}/auto/Readonly/XS/*.so
%{_mandir}/man3/*
%changelog
* Thu Jul 06 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/perl-Readonly-XS.git;a=log;h=master

* Thu Jul 06 2023 Jan Palus <atler@pld-linux.org> 20bde4a
- perl 5.38.0 rebuild

* Mon Aug 22 2022 Jan Palus <atler@pld-linux.org> fd5e368
- perl 5.36.0 rebuild

* Sun Feb 27 2022 Jan Rękorajski <baggins@pld-linux.org> f144bff
- rebuild with perl 5.34.0

* Fri May 07 2021 Jan Rękorajski <baggins@pld-linux.org> 4738f59
- rebuild with perl 5.32

* Sat Jan 25 2020 Jan Rękorajski <baggins@pld-linux.org> 42f8c18
- drop obsolete and outdated manual inclusion of rpm macros

* Wed Dec 04 2019 Jan Rękorajski <baggins@pld-linux.org> 7a7dadd
- rebuild with perl 5.30.0
- release 12 (by relup.sh)

* Thu Aug 30 2018 Jan Rękorajski <baggins@pld-linux.org> 1e544d2
- rebuild with perl 5.28.0
- release 11 (by relup.sh)

* Sun Jun 11 2017 Jan Rękorajski <baggins@pld-linux.org> 46d69b0
- perl req/prov fix
- release 10 (by relup.sh)

* Sun Jun 11 2017 Jan Rękorajski <baggins@pld-linux.org> 1da71cf
- rebuild with perl 5.26
- release 9 (by relup.sh)

* Sun Oct 30 2016 Jan Rękorajski <baggins@pld-linux.org> 5bdff1d
- rebuild with perl 5.24.0
- release 8 (by relup.sh)

* Thu Dec 24 2015 Jan Rękorajski <baggins@pld-linux.org> e3f5b2d
- release 7 (by relup.sh)

* Thu Feb 26 2015 Jan Rękorajski <baggins@pld-linux.org> 1bad800
- x32 rebuild
- release 6 (by relup.sh)

* Sat Sep 13 2014 Jan Rękorajski <baggins@pld-linux.org> 65b83ee
- release 5 (by relup.sh)

* Sat Sep 13 2014 Jan Rękorajski <baggins@pld-linux.org> 0598fac
- removed zero-sized .bs file

* Fri Sep 12 2014 Jan Rękorajski <baggins@pld-linux.org> 07e2261
- rebuild for perl 5.20
- release 4 (by relup.sh)

* Sat Jun 08 2013 Jan Rękorajski <baggins@pld-linux.org> 22b7cd3
- rebuild with perl 5.18.0
- release 3 (by relup.sh)

* Sat Dec 31 2011 Adam Gołębiowski <adamg@pld-linux.org> c3e64a5
- files fix

* Sat Dec 31 2011 Adam Gołębiowski <adamg@pld-linux.org> 88332fa
- new

